@@ -57,7 +57,7 @@ class QCticAPI:
             host = "{}://{}".format(_SCHEME_DEFAULT, host)
 
         self._req_defaults = {"headers": {"Content-Type": "application/json"}}
-        self._client = AsyncHTTPClient()
+        self._client = None
         self._host = host
         self._loop = None
 
@@ -71,7 +71,16 @@ class QCticAPI:
         try:
             return asyncio.get_running_loop()
         except (RuntimeError, AttributeError):
+            pass
+
+        try:
             return asyncio.get_event_loop()
+        except RuntimeError:
+            # It seems we are not in the main thread,
+            # thus the loop was not created implicitly.
+            asyncio.set_event_loop(asyncio.new_event_loop())
+
+        return asyncio.get_event_loop()
 
     @loop.setter
     def loop(self, val):
@@ -85,6 +94,9 @@ class QCticAPI:
     def client(self):
         """tornado.httpclient.AsyncHTTPClient: HTTP client."""
 
+        if not self._client:
+            self._client = AsyncHTTPClient()
+
         if not self.has_auth:
             raise Exception("Must authenticate first")
 
