@@ -140,17 +140,20 @@ class QCticJob(BaseJob):
         return self._remote_job.get("status", None)
 
     def _get_wait_params(self, *args, **kwargs):
-        if _PARAM_TIMEOUT in kwargs and _PARAM_WAIT in kwargs:
-            timeout = kwargs.get(_PARAM_TIMEOUT)
-            wait = kwargs.get(_PARAM_WAIT)
+        if _PARAM_TIMEOUT not in kwargs or _PARAM_WAIT not in kwargs:
+            return None
 
-            _logger.debug(
-                "Should wait for result (%s=%s, %s=%s)",
-                _PARAM_TIMEOUT, timeout, _PARAM_WAIT, wait)
+        wait = int(kwargs[_PARAM_WAIT])
+        timeout = kwargs[_PARAM_TIMEOUT]
 
-            return WaitResultParams(timeout=timeout, wait=wait)
+        if timeout is not None:
+            timeout = int(timeout)
 
-        return None
+        _logger.debug(
+            "Should wait for result (timeout=%s, wait=%s)",
+            timeout, wait)
+
+        return WaitResultParams(timeout=timeout, wait=wait)
 
     @_fetch_job_sync
     def status(self):
